@@ -608,15 +608,20 @@ def cal_performance(para_combination):
 
         # Performance by year
         first_equity_value = 0
+        last_equity_value = 0
         for year in year_list:
-            if first_equity_value == 0:
-                first_equity_value = df.loc[df['year'] == year].iloc[0].equity_value
-            last_equity_value = df.loc[df['year'] == year].iloc[-1].equity_value
-            yearly_return = (last_equity_value - first_equity_value) / first_equity_value
-            if np.isnan(yearly_return):
-                result_dict[f'{year}_return'] = 0 
-            else:
-                result_dict[f'{year}_return'] = int(yearly_return*100)
+            if not df.loc[df['year'] == year].empty: # if trade
+                if first_equity_value == 0: # if 1st year, set beginning as the first equity_value
+                    first_equity_value = df.loc[df['year'] == year].iloc[0].equity_value
+                last_equity_value = df.loc[df['year'] == year].iloc[-1].equity_value
+                yearly_return = (last_equity_value - first_equity_value) / first_equity_value
+                if np.isnan(yearly_return):
+                    result_dict[f'{year}_return'] = 0
+                else:
+                    result_dict[f'{year}_return'] = int(yearly_return*100)
+
+            else: # no trade
+                result_dict[f'{year}_return'] = '-----'
 
             first_equity_value = last_equity_value
 
